ModelTensorInfo class

Model input/output tensor info

Available extensions
Annotations

Constructors

ModelTensorInfo()

Properties

dataType → TFLiteDataType

Available on ModelTensorInfo, provided by the ModelTensorInfoExtensions extension

Data type of the tensor
no setter
dtype → String

Available on ModelTensorInfo, provided by the ModelTensorInfoExtensions extension

Data type of the tensor.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String

Available on ModelTensorInfo, provided by the ModelTensorInfoExtensions extension

Name of the tensor
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → List<int>?

Available on ModelTensorInfo, provided by the ModelTensorInfoExtensions extension

Tensor shape information
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited